==> HSFFIG-1.1.2.tar.gz: HSFFIG-1.1.2/programs/Makefile.hs <==
module Makefile where
import Data.Char
import System.IO
writeMakefile = \h -> mapM (hPutStrLn h) [
  map chr [100,101,102,105,110,101,32,109,97,107,101,45,108,105,98,114,97,114,121],
  map chr [36,40,65,87,75,41,32,39,92],
  map chr [66,69,71,73,78,32,123,92],
  map chr [32,32,97,114,103,98,117,102,61,34,34,92],
  map chr [125,92],
  map chr [123,92],
  map chr [32,32,97,114,103,98,117,102,61,97,114,103,98,117,102,32,34,32,34,32,36,36,48,32,59,92],
  map chr [32,32,105,102,32,40,108,101,110,103,116,104,40,97,114,103,98,117,102,41,32,62,32,49,54,51,56,52,41,32,123,92],
  map chr [32,32,32,32,115,121,115,116,101,109,32,40,34,36,40,65,82,41,32,113,118,32,36,64,32,34,32,97,114,103,98,117,102,41,32,59,92],
  map chr [32,32,32,32,97,114,103,98,117,102,61,34,34,92],
  map chr [32,32,125,92],
  map chr [125,92],
  map chr [69,78,68,32,123,92],
  map chr [32,32,115,121,115,116,101,109,32,40,34,36,40,65,82,41,32,113,118,32,36,64,32,34,32,97,114,103,98,117,102,41,92],
  map chr [125,92],
  map chr [39],
  map chr [101,110,100,101,102],
  map chr [],
  map chr [66,65,83,69,32,61,32,72,83,95,36,40,80,75,71,41,95,72],
  map chr [],
  map chr [97,108,108,58],
  map chr [9,64,36,40,69,67,72,79,41,32,80,108,101,97,115,101,32,100,111,32,110,111,116,32,114,117,110,32,109,97,107,101,32,100,105,114,101,99,116,108,121,58],
  map chr [9,64,36,40,69,67,72,79,41,32,85,115,101,32,114,117,110,103,104,99,32,83,101,116,117,112,46,104,115,32,116,111,32,98,117,105,108,100,32,116,104,101,32,108,105,98,114,97,114,121,46],
  map chr [],
  map chr [98,117,105,108,100,32,58,32,108,111,99,32,36,40,76,79,67,41,47,108,105,98,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,97,32,36,40,76,79,67,41,47,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,111],
  map chr [9,36,40,67,80,41,32,45,112,32,42,46,104,105,32,36,40,76,79,67,41],
  map chr [],
  map chr [108,111,99,58],
  map chr [9,45,36,40,77,75,68,73,82,41,32,45,112,32,36,40,76,79,67,41],
  map chr [],
  map chr [36,40,76,79,67,41,47,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,111,32,58,32,36,40,76,79,67,41,47,108,105,98,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,97],
  map chr [9,36,40,76,68,41,32,45,114,32,45,45,119,104,111,108,101,45,97,114,99,104,105,118,101,32,45,111,32,36,64,32,36,60],
  map chr [],
  map chr [36,40,76,79,67,41,47,108,105,98,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,97,32,58,32,36,40,66,65,83,69,41,46,104,115,99],
  map chr [9,36,40,69,67,72,79,41,32,34,105,110,99,108,117,100,101,32,77,97,107,101,102,105,108,101,34,32,62,32,36,40,66,65,83,69,41,95,100,101,112,101,110,100],
  map chr [9,36,40,71,72,67,41,32,45,112,97,99,107,97,103,101,32,72,83,70,70,73,71,32,45,77,32,36,40,66,65,83,69,41,42,46,104,115,32,45,100,101,112,45,109,97,107,101,102,105,108,101,32,36,40,66,65,83,69,41,95,100,101,112,101,110,100],
  map chr [9,36,40,71,72,67,41,32,45,99,32,36,40,66,65,83,69,41,95,104,115,99,46,99],
  map chr [9,36,40,77,65,75,69,41,32,45,102,32,36,40,66,65,83,69,41,95,100,101,112,101,110,100,32,36,40,66,65,83,69,41,95,83,95,116,46,111,32,36,40,66,65,83,69,41,95,83,95,110,46,111,32,36,40,66,65,83,69,41,95,83,95,100,46,111,32,92],
  map chr [9,9,36,40,66,65,83,69,41,95,67,46,111,32,36,40,66,65,83,69,41,95,83,46,111,32,36,40,66,65,83,69,41,46,111],
  map chr [9,36,40,82,77,41,32,45,102,32,36,64],
  map chr [9,36,40,65,82,41,32,99,113,32,36,64,32,36,40,66,65,83,69,41,95,104,115,99,46,111,32,36,40,69,88,84,82,65,95,79,66,74,41],
  map chr [9,36,40,70,73,78,68,41,32,46,32,45,110,97,109,101,32,39,36,40,66,65,83,69,41,42,46,111,39,32,124,32,36,40,71,82,69,80,41,32,39,115,112,108,105,116,47,39,32,124,32,36,40,109,97,107,101,45,108,105,98,114,97,114,121,41],
  map chr [],
  map chr [],
  map chr [37,46,104,105,32,37,46,111,32,58,32,37,46,104,115],
  map chr [9,45,36,40,77,75,68,73,82,41,32,36,42,95,115,112,108,105,116,32,50,62,47,100,101,118,47,110,117,108,108],
  map chr [9,36,40,69,67,72,79,41,32,34,105,110,116,32,100,117,109,109,121,95,36,42,95,115,116,117,98,95,101,110,116,114,121,59,34,32,124,32,36,40,71,67,67,41,32,45,120,32,99,32,45,99,32,45,111,32,36,42,46,111,32,45],
  map chr [9,36,40,71,72,67,41,32,45,112,97,99,107,97,103,101,45,110,97,109,101,32,36,40,80,75,71,41,45,36,40,86,69,82,41,32,45,115,112,108,105,116,45,111,98,106,115,32,45,99,32,45,112,97,99,107,97,103,101,32,72,83,70,70,73,71,32,36,60],
  map chr [9,36,40,84,79,85,67,72,41,32,36,42,46,111,32,36,42,46,104,105],
  map chr [],
  map chr [37,46,104,105,32,58,32,37,46,111],
  map chr [9,36,40,84,82,85,69,41],
  map chr [],
  map chr [] ]

==> HSFFIG-1.1.3.tar.gz: HSFFIG-1.1.3/programs/Makefile.hs <==
module Makefile where
import Data.Char
import System.IO
writeMakefile = \h -> mapM (hPutStrLn h) [
  map chr [100,101,102,105,110,101,32,109,97,107,101,45,108,105,98,114,97,114,121],
  map chr [36,40,65,87,75,41,32,39,92],
  map chr [66,69,71,73,78,32,123,92],
  map chr [32,32,97,114,103,98,117,102,61,34,34,92],
  map chr [125,92],
  map chr [123,92],
  map chr [32,32,97,114,103,98,117,102,61,97,114,103,98,117,102,32,34,32,34,32,36,36,48,32,59,92],
  map chr [32,32,105,102,32,40,108,101,110,103,116,104,40,97,114,103,98,117,102,41,32,62,32,49,54,51,56,52,41,32,123,92],
  map chr [32,32,32,32,115,121,115,116,101,109,32,40,34,36,40,65,82,41,32,113,118,32,36,64,32,34,32,97,114,103,98,117,102,41,32,59,92],
  map chr [32,32,32,32,97,114,103,98,117,102,61,34,34,92],
  map chr [32,32,125,92],
  map chr [125,92],
  map chr [69,78,68,32,123,92],
  map chr [32,32,115,121,115,116,101,109,32,40,34,36,40,65,82,41,32,113,118,32,36,64,32,34,32,97,114,103,98,117,102,41,92],
  map chr [125,92],
  map chr [39],
  map chr [101,110,100,101,102],
  map chr [],
  map chr [66,65,83,69,32,61,32,72,83,95,36,40,80,75,71,41,95,72],
  map chr [],
  map chr [97,108,108,58],
  map chr [9,64,36,40,69,67,72,79,41,32,80,108,101,97,115,101,32,100,111,32,110,111,116,32,114,117,110,32,109,97,107,101,32,100,105,114,101,99,116,108,121,58],
  map chr [9,64,36,40,69,67,72,79,41,32,85,115,101,32,114,117,110,103,104,99,32,83,101,116,117,112,46,104,115,32,116,111,32,98,117,105,108,100,32,116,104,101,32,108,105,98,114,97,114,121,46],
  map chr [],
  map chr [98,117,105,108,100,32,58,32,108,111,99,32,36,40,76,79,67,41,47,108,105,98,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,97,32,36,40,76,79,67,41,47,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,111],
  map chr [9,36,40,67,80,41,32,45,112,32,42,46,104,105,32,36,40,76,79,67,41],
  map chr [],
  map chr [108,111,99,58],
  map chr [9,45,36,40,77,75,68,73,82,41,32,45,112,32,36,40,76,79,67,41],
  map chr [],
  map chr [36,40,76,79,67,41,47,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,111,32,58,32,36,40,76,79,67,41,47,108,105,98,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,97],
  map chr [9,36,40,76,68,41,32,45,114,32,45,45,119,104,111,108,101,45,97,114,99,104,105,118,101,32,45,111,32,36,64,32,36,60],
  map chr [],
  map chr [36,40,76,79,67,41,47,108,105,98,72,83,36,40,80,75,71,41,45,36,40,86,69,82,41,46,97,32,58,32,36,40,66,65,83,69,41,46,104,115,99],
  map chr [9,36,40,69,67,72,79,41,32,34,105,110,99,108,117,100,101,32,77,97,107,101,102,105,108,101,34,32,62,32,36,40,66,65,83,69,41,95,100,101,112,101,110,100],
  map chr [9,36,40,71,72,67,41,32,45,112,97,99,107,97,103,101,32,72,83,70,70,73,71,32,45,77,32,36,40,66,65,83,69,41,42,46,104,115,32,45,100,101,112,45,109,97,107,101,102,105,108,101,32,36,40,66,65,83,69,41,95,100,101,112,101,110,100],
  map chr [9,36,40,71,72,67,41,32,45,99,32,36,40,66,65,83,69,41,95,104,115,99,46,99],
  map chr [9,36,40,77,65,75,69,41,32,45,102,32,36,40,66,65,83,69,41,95,100,101,112,101,110,100,32,36,40,66,65,83,69,41,95,83,95,116,46,111,32,36,40,66,65,83,69,41,95,83,95,110,46,111,32,36,40,66,65,83,69,41,95,83,95,100,46,111,32,92],
  map chr [9,9,36,40,66,65,83,69,41,95,67,46,111,32,36,40,66,65,83,69,41,95,83,46,111,32,36,40,66,65,83,69,41,46,111],
  map chr [9,36,40,82,77,41,32,45,102,32,36,64],
  map chr [9,36,40,65,82,41,32,99,113,32,36,64,32,36,40,66,65,83,69,41,95,104,115,99,46,111,32,36,40,69,88,84,82,65,95,79,66,74,41],
  map chr [9,36,40,70,73,78,68,41,32,46,32,45,110,97,109,101,32,39,36,40,66,65,83,69,41,42,46,111,39,32,124,32,36,40,71,82,69,80,41,32,45,69,32,39,115,112,108,105,116,47,124,115,116,117,98,39,32,124,32,36,40,109,97,107,101,45,108,105,98,114,97,114,121,41],
  map chr [],
  map chr [],
  map chr [37,46,104,105,32,37,46,111,32,58,32,37,46,104,115],
  map chr [9,45,36,40,77,75,68,73,82,41,32,36,42,95,115,112,108,105,116,32,50,62,47,100,101,118,47,110,117,108,108],
  map chr [9,36,40,69,67,72,79,41,32,34,105,110,116,32,100,117,109,109,121,95,36,42,95,115,116,117,98,95,101,110,116,114,121,59,34,32,124,32,36,40,71,67,67,41,32,45,120,32,99,32,45,99,32,45,111,32,36,42,46,111,32,45],
  map chr [9,36,40,71,72,67,41,32,45,112,97,99,107,97,103,101,45,110,97,109,101,32,36,40,80,75,71,41,45,36,40,86,69,82,41,32,45,115,112,108,105,116,45,111,98,106,115,32,45,99,32,45,112,97,99,107,97,103,101,32,72,83,70,70,73,71,32,36,60],
  map chr [9,36,40,84,79,85,67,72,41,32,36,42,46,111,32,36,42,46,104,105],
  map chr [],
  map chr [37,46,104,105,32,58,32,37,46,111],
  map chr [9,36,40,84,82,85,69,41],
  map chr [],
  map chr [] ]
